/*
 *  
 *  $Id: paneltarea.h 4359 2011-11-02 08:16:57Z tovar $
 *  Ginkgo CADx Project
 *
 *  Copyright 2008-10 MetaEmotion S.L. All rights reserved.
 *  http://ginkgo-cadx.com
 *
 *  This file is licensed under LGPL v3 license.
 *  See License.txt for details
 *
 *
 */
#include "progresobase.h"
namespace GNC {
	namespace GUI {
		
		class PanelTarea : public PanelTareaBase {
		public:
			PanelTarea( wxWindow* pPadre,long pidTarea);
			~PanelTarea();

			void SetProgress(const wxString& text, float progress);
			wxString GetStatus();
			float GetProgress();
		protected:
			void OnTareaCancelarClick(wxCommandEvent &event);
			long m_PIDTarea;
		};
	}
}
